@@ -20,7 +20,7 @@ has options => sub {
 };
 has [qw(password username)] => '';
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 sub db {
   my $self = shift;
@@ -28,7 +28,8 @@ sub db {
   # Fork safety
   delete @$self{qw(pid queue)} unless ($self->{pid} //= $$) eq $$;
 
-  return Mojo::Pg::Database->new(dbh => $self->_dequeue, pg => $self);
+  my ($dbh, $handle) = @{$self->_dequeue};
+  return Mojo::Pg::Database->new(dbh => $dbh, handle => $handle, pg => $self);
 }
 
 sub from_string {
@@ -68,16 +69,16 @@ sub new { @_ > 1 ? shift->SUPER::new->from_string(@_) : shift->SUPER::new }
 
 sub _dequeue {
   my $self = shift;
-  while (my $dbh = shift @{$self->{queue} || []}) { return $dbh if $dbh->ping }
+  while (my $c = shift @{$self->{queue} || []}) { return $c if $c->[0]->ping }
   my $dbh = DBI->connect(map { $self->$_ } qw(dsn username password options));
   $self->emit(connection => $dbh);
-  return $dbh;
+  return [$dbh];
 }
 
 sub _enqueue {
-  my ($self, $dbh) = @_;
+  my ($self, $dbh, $handle) = @_;
   my $queue = $self->{queue} ||= [];
-  push @$queue, $dbh if $dbh->{Active};
+  push @$queue, [$dbh, $handle] if $dbh->{Active};
   shift @$queue while @$queue > $self->max_connections;
 }
 
