@@ -13,7 +13,8 @@ has max_statements => 10;
 
 sub DESTROY {
   my $self = shift;
-  if ((my $dbh = $self->dbh) && (my $pg = $self->pg)) { $pg->_enqueue($dbh) }
+  return unless my $pg = $self->pg;
+  if (my $dbh = $self->dbh) { $pg->_enqueue($dbh, $self->{handle}) }
 }
 
 sub backlog { scalar @{shift->{waiting} || []} }
